@@ -1,4 +1,4 @@
-package Evo::GA::Population;
+package Evo::GA::Genome;
 
 sub new {
 	my ($class) = @_;
@@ -10,6 +10,26 @@ sub new {
 	bless $self, $class;
 }
 
+sub mutate_simple {
+	my ($self, $idx) = @_;
+
+	$self->{genes}[$idx] = - $self->{genes}[$idx];
+}
+
+sub crossover_simple {
+	my ($self, $idx1, $idx2, $genome) = @_;
+
+	for (my $i = $idx1; $i < $idx2; $i++) {
+		$self->{genes}[$i] = $genome->{genes}[$i] + $self->{genes}[$i]; ### FIXME
+	}
+}
+
+sub add_to {
+	my ($self, $gene) = @_;
+
+	push (@{$self->{genes}}, $gene);
+}
+
 ### estimate fitness function
 sub fitness_simple {
 	my ($self) = @_;
