@@ -11,6 +11,12 @@ sub new {
 	bless $self, $class;
 }
 
+sub add_to {
+	my ($self, $genome) = @_;
+
+	push (@{$self->{population}}, $genome);
+}
+
 sub fittest_simple {
 	my ($self) = @_;
 	my $fittest_genome = undef;
